#!/usr/bin/perl

##########################################################################
#
#  pumpscript.pl - September 22, 1999 - Graham Mainwaring <graham@mhn.org>
#
#  This is an example script intended to be called from pump when an
#  interface receives its DHCP configuration. It is passed a series of
#  key=value pairs on stdin, which contain the information that pump
#  was able to gather from the DHCP server. It is not guaranteed that
#  any particular item will necessarily be available. The script must
#  also silently ignore any unknown items that arrive. Note that there
#  is no reason to ever use this script exactly as it is given here;
#  if all you want is default behavior, just use pump's built-in
#  routines. This scripting capability is intended for people who
#  want to customize the behavior of what happens when you get your
#  dhcp information, for whatever bizarre purpose.
#
##########################################################################

use Sys::Syslog;

sub logerr($) {
  openlog('pumpd', 'cons,pid', 'daemon');
  syslog('err', $_[0]);
  closelog();
}

sub errexit($) {
  logerr($_[0]);
  die $_[0];
}

while (<>) {
  chop;
  ($tag,$value)=split(/\=/);
  $tag=lc($tag);
  if ($tag eq "dev") { $dev = $value }
  elsif ($tag eq "ip") { $ip = $value }
  elsif ($tag eq "netmask") { $netmask = $value }
  elsif ($tag eq "broadcast") { $broadcast = $value }
  elsif ($tag eq "network") { $network = $value }
  elsif ($tag eq "gateway") { $gateway = $value }
  elsif ($tag eq "hostname") { $hostname = $value }
  elsif ($tag eq "domain") { $domain = $value }
  elsif ($tag =~ /dns[0-9]/) { $dns[$#dns+1] = $value }
}

if (defined $dev && defined $ip && defined $netmask && defined $broadcast) {
  system "/sbin/ifconfig $dev $ip netmask $netmask broadcast $broadcast";
} else {
  errexit("did not get enough information to configure interface");
}

if (defined $gateway) {
  system "/sbin/route del default";
  system "/sbin/route add default gw $gateway";
} else {
  logerr("did not get a default gateway");
}

if (defined $hostname) {
  system "/bin/hostname $hostname";
}

if ($#dns >= 0) {
  open RESOLV, ">/etc/resolv.conf";
  if ($domain ne "") { print RESOLV "domain $domain\n"; }
  print RESOLV "nameserver ";
  foreach $dns (@dns) {
    print RESOLV "$dns ";
  }
  print RESOLV "\n";
  close RESOLV;
}
